#  tests for preshed-1.0.0-py37hf484d3e_0 (this is a generated file);
print('===== testing package: preshed-1.0.0-py37hf484d3e_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import preshed
import pytest

PACKAGE_DIR = os.path.abspath(os.path.dirname(preshed.__file__))
pytest.main([PACKAGE_DIR])
#  --- run_test.py (end) ---

print('===== preshed-1.0.0-py37hf484d3e_0 OK =====');
print("import: 'preshed'")
import preshed

print("import: 'preshed.counter'")
import preshed.counter

print("import: 'preshed.maps'")
import preshed.maps

print("import: 'preshed.tests'")
import preshed.tests

